@@ -21,7 +21,7 @@
 #ifndef _CREATEMATRIXDLG_H
 #define _CREATEMATRIXDLG_H
 
-#include <kdialog.h>
+#include <KDialog>
 #include "ui_creatematrixdlg.h"
 
 class CreateMatrixDlg : public KDialog
@@ -36,7 +36,7 @@ class CreateMatrixDlg : public KDialog
 
     QString value(int i,int j);
 
-  public slots:
+  public Q_SLOTS:
     void changeNumRows(int rows);
     void changeNumCols(int cols);
 
